==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/ucb/XDynamicResultSet.hpp <==
#ifndef _COM_SUN_STAR_UCB_XDYNAMICRESULTSET_HPP_
#define _COM_SUN_STAR_UCB_XDYNAMICRESULTSET_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_UCB_XDYNAMICRESULTSET_HDL_
#include "com/sun/star/ucb/XDynamicResultSet.hdl"
#endif

#ifndef _COM_SUN_STAR_UCB_XDYNAMICRESULTSETLISTENER_HPP_
#include "com/sun/star/ucb/XDynamicResultSetListener.hpp"
#endif
#ifndef _COM_SUN_STAR_LANG_XCOMPONENT_HPP_
#include "com/sun/star/lang/XComponent.hpp"
#endif
#ifndef _COM_SUN_STAR_SDBC_XRESULTSET_HPP_
#include "com/sun/star/sdbc/XResultSet.hpp"
#endif
#ifndef _COM_SUN_STAR_UCB_SERVICENOTFOUNDEXCEPTION_HPP_
#include "com/sun/star/ucb/ServiceNotFoundException.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_RUNTIMEEXCEPTION_HPP_
#include "com/sun/star/uno/RuntimeException.hpp"
#endif
#ifndef _COM_SUN_STAR_UCB_ALREADYINITIALIZEDEXCEPTION_HPP_
#include "com/sun/star/ucb/AlreadyInitializedException.hpp"
#endif
#ifndef _COM_SUN_STAR_UCB_LISTENERALREADYSETEXCEPTION_HPP_
#include "com/sun/star/ucb/ListenerAlreadySetException.hpp"
#endif
#ifndef _COM_SUN_STAR_UCB_XDYNAMICRESULTSET_HPP_
#include "com/sun/star/ucb/XDynamicResultSet.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_REFERENCE_HXX_
#include "com/sun/star/uno/Reference.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif

inline const ::com::sun::star::uno::Type& SAL_CALL getCppuType( const ::com::sun::star::uno::Reference< ::com::sun::star::ucb::XDynamicResultSet >* ) SAL_THROW( () )
{
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_INTERFACE, "com.sun.star.ucb.XDynamicResultSet" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
}

::com::sun::star::uno::Type const & ::com::sun::star::ucb::XDynamicResultSet::static_type(void *) {
    return ::getCppuType(static_cast< ::com::sun::star::uno::Reference< ::com::sun::star::ucb::XDynamicResultSet > * >(0));
}

#endif // _COM_SUN_STAR_UCB_XDYNAMICRESULTSET_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/ucb/XDynamicResultSet.hpp <==
#ifndef _COM_SUN_STAR_UCB_XDYNAMICRESULTSET_HPP_
#define _COM_SUN_STAR_UCB_XDYNAMICRESULTSET_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_UCB_XDYNAMICRESULTSET_HDL_
#include "com/sun/star/ucb/XDynamicResultSet.hdl"
#endif

#ifndef _COM_SUN_STAR_UCB_XDYNAMICRESULTSETLISTENER_HPP_
#include "com/sun/star/ucb/XDynamicResultSetListener.hpp"
#endif
#ifndef _COM_SUN_STAR_LANG_XCOMPONENT_HPP_
#include "com/sun/star/lang/XComponent.hpp"
#endif
#ifndef _COM_SUN_STAR_SDBC_XRESULTSET_HPP_
#include "com/sun/star/sdbc/XResultSet.hpp"
#endif
#ifndef _COM_SUN_STAR_UCB_SERVICENOTFOUNDEXCEPTION_HPP_
#include "com/sun/star/ucb/ServiceNotFoundException.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_RUNTIMEEXCEPTION_HPP_
#include "com/sun/star/uno/RuntimeException.hpp"
#endif
#ifndef _COM_SUN_STAR_UCB_ALREADYINITIALIZEDEXCEPTION_HPP_
#include "com/sun/star/ucb/AlreadyInitializedException.hpp"
#endif
#ifndef _COM_SUN_STAR_UCB_LISTENERALREADYSETEXCEPTION_HPP_
#include "com/sun/star/ucb/ListenerAlreadySetException.hpp"
#endif
#ifndef _COM_SUN_STAR_UCB_XDYNAMICRESULTSET_HPP_
#include "com/sun/star/ucb/XDynamicResultSet.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_REFERENCE_HXX_
#include "com/sun/star/uno/Reference.hxx"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _OSL_MUTEX_HXX_
#include "osl/mutex.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif

namespace com { namespace sun { namespace star { namespace ucb {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::ucb::XDynamicResultSet const *) {
    static typelib_TypeDescriptionReference * the_type = 0;
    if ( !the_type )
    {
        typelib_static_type_init( &the_type, typelib_TypeClass_INTERFACE, "com.sun.star.ucb.XDynamicResultSet" );
    }
    return * reinterpret_cast< ::com::sun::star::uno::Type * >( &the_type );
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::uno::Reference< ::com::sun::star::ucb::XDynamicResultSet > const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::uno::Reference< ::com::sun::star::ucb::XDynamicResultSet > >::get();
}

::com::sun::star::uno::Type const & ::com::sun::star::ucb::XDynamicResultSet::static_type(void *) {
    return ::getCppuType(static_cast< ::com::sun::star::uno::Reference< ::com::sun::star::ucb::XDynamicResultSet > * >(0));
}

#endif // _COM_SUN_STAR_UCB_XDYNAMICRESULTSET_HPP_
